@@ -267,7 +267,8 @@ gst_ffmpegdemux_init (GstFFMpegDemux * demux)
   gst_pad_set_chain_function (demux->sinkpad,
       GST_DEBUG_FUNCPTR (gst_ffmpegdemux_chain));
   /* task for driving ffmpeg in loop function */
-  demux->task = gst_task_new ((GstTaskFunction) gst_ffmpegdemux_loop, demux);
+  demux->task =
+      gst_task_new ((GstTaskFunction) gst_ffmpegdemux_loop, demux, NULL);
   g_rec_mutex_init (&demux->task_lock);
   gst_task_set_lock (demux->task, &demux->task_lock);
 
@@ -330,7 +331,7 @@ gst_ffmpegdemux_close (GstFFMpegDemux * demux)
       if (stream->pad)
         gst_element_remove_pad (GST_ELEMENT (demux), stream->pad);
       if (stream->tags)
-        gst_tag_list_free (stream->tags);
+        gst_tag_list_unref (stream->tags);
       g_free (stream);
     }
     demux->streams[n] = NULL;
@@ -630,7 +631,7 @@ gst_ffmpegdemux_perform_seek (GstFFMpegDemux * demux, GstEvent * event)
   /* and restart the task in case it got paused explicitely or by
    * the FLUSH_START event we pushed out. */
   gst_pad_start_task (demux->sinkpad, (GstTaskFunction) gst_ffmpegdemux_loop,
-      demux->sinkpad);
+      demux->sinkpad, NULL);
 
   /* and release the lock again so we can continue streaming */
   GST_PAD_STREAM_UNLOCK (demux->sinkpad);
@@ -925,6 +926,7 @@ gst_ffmpegdemux_get_stream (GstFFMpegDemux * demux, AVStream * avstream)
   const gchar *codec;
   AVCodecContext *ctx;
   GstFFStream *stream;
+  gchar *stream_id;
 
   ctx = avstream->codec;
 
@@ -975,8 +977,6 @@ gst_ffmpegdemux_get_stream (GstFFMpegDemux * demux, AVStream * avstream)
 
   gst_pad_use_fixed_caps (pad);
   gst_pad_set_active (pad, TRUE);
-  gst_pad_set_caps (pad, caps);
-  gst_caps_unref (caps);
 
   gst_pad_set_query_function (pad, gst_ffmpegdemux_src_query);
   gst_pad_set_event_function (pad, gst_ffmpegdemux_src_event);
@@ -1001,6 +1001,16 @@ gst_ffmpegdemux_get_stream (GstFFMpegDemux * demux, AVStream * avstream)
 
   demux->streams[avstream->index] = stream;
 
+
+  stream_id =
+      gst_pad_create_stream_id_printf (pad, GST_ELEMENT_CAST (demux), "%u",
+      avstream->index);
+  gst_pad_push_event (pad, gst_event_new_stream_start (stream_id));
+  g_free (stream_id);
+
+  gst_pad_set_caps (pad, caps);
+  gst_caps_unref (caps);
+
   /* activate and add */
   gst_element_add_pad (GST_ELEMENT (demux), pad);
 
@@ -1102,7 +1112,7 @@ gst_ffmpegdemux_read_tags (GstFFMpegDemux * demux)
   }
 
   if (!hastag) {
-    gst_tag_list_free (tlist);
+    gst_tag_list_unref (tlist);
     tlist = NULL;
   }
   return tlist;
@@ -1221,7 +1231,7 @@ gst_ffmpegdemux_open (GstFFMpegDemux * demux)
       GST_INFO_OBJECT (stream->pad, "stream tags: %" GST_PTR_FORMAT,
           stream->tags);
       gst_pad_push_event (stream->pad,
-          gst_event_new_tag (gst_tag_list_copy (stream->tags)));
+          gst_event_new_tag (gst_tag_list_ref (stream->tags)));
     }
   }
 
@@ -1484,6 +1494,8 @@ pause:
         gst_element_post_message (GST_ELEMENT (demux),
             gst_message_new_segment_done (GST_OBJECT (demux),
                 demux->segment.format, stop));
+        gst_ffmpegdemux_push_event (demux,
+            gst_event_new_segment_done (demux->segment.format, stop));
       } else {
         GST_LOG_OBJECT (demux, "pushing eos");
         gst_ffmpegdemux_push_event (demux, gst_event_new_eos ());
@@ -1778,7 +1790,7 @@ gst_ffmpegdemux_sink_activate_pull (GstPad * sinkpad, GstObject * parent,
   if (active) {
     demux->seekable = TRUE;
     res = gst_pad_start_task (sinkpad, (GstTaskFunction) gst_ffmpegdemux_loop,
-        demux);
+        demux, NULL);
   } else {
     res = gst_pad_stop_task (sinkpad);
     demux->seekable = FALSE;
